.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        Click :ref:`here <sphx_glr_download_auto_examples_plot_svg.py>`     to download the full example code
    .. rst-class:: sphx-glr-example-title

    .. _sphx_glr_auto_examples_plot_svg.py:


==================
"SVG":-`graphics_`
==================

Make sure we can embed SVG graphics.
Use title that has punctuation marks.



.. image:: /auto_examples/images/sphx_glr_plot_svg_001.svg
    :alt: plot svg
    :class: sphx-glr-single-img


.. rst-class:: sphx-glr-script-out

 Out:

 .. code-block:: none


    Text(0, 1, 'svg')





|


.. code-block:: python3


    import numpy as np
    import matplotlib.pyplot as plt

    from local_module import N  # N = 1000

    t = np.arange(N) / float(N)
    win = np.hanning(N)
    plt.figure()
    plt.plot(t, win, color='r')
    plt.text(0, 1, 'svg', size=40, va='top')


.. rst-class:: sphx-glr-timing

   **Total running time of the script:** ( 0 minutes  0.085 seconds)


.. _sphx_glr_download_auto_examples_plot_svg.py:


.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-example



  .. container:: sphx-glr-download sphx-glr-download-python

     :download:`Download Python source code: plot_svg.py <plot_svg.py>`



  .. container:: sphx-glr-download sphx-glr-download-jupyter

     :download:`Download Jupyter notebook: plot_svg.ipynb <plot_svg.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
